@@ -3,7 +3,7 @@ function(A){
   k <- dim(A)
   k1 <- k[1]
   k2 <- k[2]
-  s <- matrix(A,nr=k1*k2,nc=1)
+  s <- matrix(A,nrow=k1*k2,ncol=1)
   s
 }
 
